==> vlc-1.2.0-pre4.tar.xz: vlc-1.2.0-pre4/modules/stream_filter/dash/mpd/Period.cpp <==
/*
 * Period.cpp
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "Period.h"

using namespace dash::mpd;

Period::Period  (std::map<std::string, std::string> attributes)
{
    this->attributes = attributes;
}
Period::~Period ()
{
    for(size_t i = 0; i < this->groups.size(); i++)
        delete(this->groups.at(i));
}

std::vector<Group*> Period::getGroups   ()
{
    return this->groups;
}
void                Period::addGroup    (Group *group)
{
    this->groups.push_back(group);
}

==> vlc-2.0.6.tar.xz: vlc-2.0.6/modules/stream_filter/dash/mpd/Period.cpp <==
/*
 * Period.cpp
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "Period.h"

#include <vlc_common.h>
#include <vlc_arrays.h>

using namespace dash::mpd;

Period::Period()
{
}

Period::~Period ()
{
    vlc_delete_all( this->groups );
}

const std::vector<Group*>&      Period::getGroups() const
{
    return this->groups;
}

void                Period::addGroup(Group *group)
{
    if ( group != NULL )
        this->groups.push_back(group);
}
